#include "arona_application.h"
#include "wx/app.h"
#include "wx/frame.h"
#include "wx/msgdlg.h"
#include "wx/menu.h"
#include "wx/sysopt.h"

enum {
    ID_Hello = 1
};

class test_frame : public wxFrame {
public:
    test_frame(const wxString& title, const wxPoint& pos, const wxSize& size)
        : wxFrame(nullptr, wxID_ANY, title, pos, size) {
        SetFont(wxFont(12, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL, false, "Arial"));

        auto menu_file = new wxMenu;
        menu_file->Append(ID_Hello, "&Hello...\tCtrl-H",
            "Help string shown in status bar for this menu item");
        menu_file->AppendSeparator();
        menu_file->Append(wxID_EXIT);

        auto menu_help = new wxMenu;
        menu_help->Append(wxID_ABOUT);

        auto menu_bar = new wxMenuBar;
        menu_bar->Append(menu_file, "&File");
        menu_bar->Append(menu_help, "&Help");

        wxFrameBase::SetMenuBar(menu_bar);
        wxFrameBase::CreateStatusBar();
        wxFrameBase::SetStatusText("Welcome to wxWidgets!");
        GetHandle();
    }
private:
    void OnHello(wxCommandEvent& event) {
        wxMessageBox("Hello world from wxWidgets!");
    }
    void OnExit(wxCommandEvent& event) {
        Close(true);
    }
    void OnAbout(wxCommandEvent& event) {
        wxMessageBox("This is a wxWidgets' Hello world sample",
            "About Hello World", wxOK | wxICON_INFORMATION);
    }
    wxDECLARE_EVENT_TABLE();
};
wxBEGIN_EVENT_TABLE(test_frame, wxFrame)
    EVT_MENU(ID_Hello, test_frame::OnHello)
    EVT_MENU(wxID_EXIT, test_frame::OnExit)
    EVT_MENU(wxID_ABOUT, test_frame::OnAbout)
wxEND_EVENT_TABLE()

class arona_app : public wxApp {
public:
    bool OnInit() override {
        if (!wxApp::OnInit())
            return false;
        // 设置高DPI支持
#if PLATFORM_WINDOWS
        if (wxPlatformInfo::Get().CheckOSVersion(10, 0)) {
            wxSystemOptions::SetOption("msw.highdpi.support", 1);
        }
#endif
#if PLATFORM_LINUX
        if (wxPlatformInfo::Get().GetOperatingSystemId() == wxOS_UNIX_LINUX) {
            wxSystemOptions::SetOption("gtk.window.force-hidpi", 1);
        }
#endif

        arona.init(nullptr);
        const auto frame = new test_frame(_("Display wxWidgets Sample"), wxPoint(50, 50), wxSize(450, 340));
        frame->Show(true);
        return true;
    }
    int OnExit() override {
        arona.shutdown();
        return wxApp::OnExit();
    }
private:
    arona_application arona;
};
wxIMPLEMENT_APP(arona_app);
